diff libpurple/protocols/msn/servconn.h @ 15823:32c366eeeb99

sed -ie 's/gaim/purple/g'
author Sean Egan <seanegan@gmail.com>
date Mon, 19 Mar 2007 07:01:17 +0000
parents 5fe8042783c1
children 44b4e8bd759b
line wrap: on
line diff
--- a/libpurple/protocols/msn/servconn.h	Mon Mar 19 06:11:46 2007 +0000
+++ b/libpurple/protocols/msn/servconn.h	Mon Mar 19 07:01:17 2007 +0000
@@ -1,9 +1,9 @@
 /**
  * @file servconn.h Server connection functions
  *
- * gaim
+ * purple
  *
  * Gaim is the legal property of its developers, whose names are too numerous
  * to list here.  Please refer to the COPYRIGHT file distributed with this
  * source distribution.
  *
@@ -63,7 +63,7 @@
 	MsnSession *session;  /**< The MSN session of this connection. */
 	MsnCmdProc *cmdproc;  /**< The command processor of this connection. */
 
-	GaimProxyConnectData *connect_data;
+	PurpleProxyConnectData *connect_data;
 
 	gboolean connected;   /**< A flag that states if it's connected. */
 	gboolean processing;  /**< A flag that states if something is working
@@ -86,7 +86,7 @@
 						  It's only set when we've received a command that
 						  has a payload. */
 
-	GaimCircBuffer *tx_buf;
+	PurpleCircBuffer *tx_buf;
 	guint tx_handler;
 
 	void (*connect_cb)(MsnServConn *); /**< The callback to call when connecting. */
@@ -1,9 +1,9 @@
  *
- * Gaim is the legal property of its developers, whose names are too numerous
+ * Purple is the legal property of its developers, whose names are too numerous
  * to list here.  Please refer to the COPYRIGHT file distributed with this
  * source distribution.